@@ -1,11 +1,13 @@
 from __future__ import annotations
 
 from enum import EnumMeta
-from typing import TYPE_CHECKING, Any, Callable, Literal, Mapping, TypeVar
+from typing import TYPE_CHECKING, Any, Callable, Literal, TypeVar
 
 from polyfactory.exceptions import ParameterException
 
 if TYPE_CHECKING:
+    from collections.abc import Mapping
+
     from polyfactory.factories.base import BaseFactory, BuildContext
     from polyfactory.field_meta import FieldMeta
 
