@@ -1,16 +1,15 @@
 from datetime import date, datetime, timedelta
 from decimal import Decimal
-from typing import FrozenSet, List, Set, Tuple, Type, Union, cast
+from typing import Annotated, Union, cast
 
 import pytest
-from typing_extensions import Annotated
 
 from polyfactory.factories.base import BaseFactory
 from polyfactory.field_meta import Constraints, FieldMeta
 
 
 @pytest.mark.parametrize("t", (int, float, Decimal))
-def test_numbers(t: Type[Union[int, float, Decimal]]) -> None:
+def test_numbers(t: type[Union[int, float, Decimal]]) -> None:
     constraints: Constraints = {"ge": 1, "le": 20}
     field_meta = FieldMeta.from_type(annotation=t, name="foo", constraints=constraints)
     value = BaseFactory.get_field_value(field_meta)
@@ -20,7 +19,7 @@ def test_numbers(t: Type[Union[int, float, Decimal]]) -> None:
 
 
 @pytest.mark.parametrize("t", (str, bytes))
-def test_str_and_bytes(t: Type[Union[str, bytes]]) -> None:
+def test_str_and_bytes(t: type[Union[str, bytes]]) -> None:
     constraints: Constraints = {"min_length": 20, "max_length": 45}
     field_meta = FieldMeta.from_type(annotation=t, name="foo", constraints=constraints)
     value = BaseFactory.get_field_value(field_meta)
@@ -29,8 +28,8 @@ def test_str_and_bytes(t: Type[Union[str, bytes]]) -> None:
     assert len(value) <= constraints["max_length"]
 
 
-@pytest.mark.parametrize("t", (List[int], Set[int], Tuple[int], FrozenSet[int]))
-def test_collections(t: Type[Union[Tuple, List, Set, FrozenSet]]) -> None:
+@pytest.mark.parametrize("t", (list[int], set[int], tuple[int], frozenset[int]))
+def test_collections(t: type[Union[tuple, list, set, frozenset]]) -> None:
     constraints: Constraints = {
         "min_length": 2,
         "max_length": 10,
