@@ -2,7 +2,7 @@ from sqlalchemy import select
 from sqlalchemy.ext.asyncio import AsyncEngine, AsyncSession
 
 from polyfactory.factories.sqlalchemy_factory import SQLAlchemyFactory
-from tests.sqlalchemy_factory.models import Keyword, User, UserKeywordAssociation
+from tests.sqlalchemy_factory.models import Company, Keyword, User, UserKeywordAssociation
 
 
 class KeywordFactory(SQLAlchemyFactory[Keyword]): ...
@@ -18,6 +18,26 @@ def test_association_proxy() -> None:
     assert isinstance(user.user_keyword_associations[0], UserKeywordAssociation)
 
 
+def test_association_proxy_no_creator() -> None:
+    class CompanyFactory(SQLAlchemyFactory[Company]):
+        __set_relationships__ = True
+        __set_association_proxy__ = True
+
+    company = CompanyFactory.build()
+    assert isinstance(company.employee_ids[0], int)
+    assert company.employees[0].id in company.employee_ids
+
+
+def test_association_proxy_no_creator_no_relationship() -> None:
+    class CompanyFactory(SQLAlchemyFactory[Company]):
+        __set_relationships__ = False
+        __set_association_proxy__ = True
+
+    company = CompanyFactory.build()
+    assert len(company.employees) == 0
+    assert len(company.employee_ids) == 0
+
+
 async def test_async_persistence(async_engine: AsyncEngine) -> None:
     async with AsyncSession(async_engine) as session:
 
