@@ -1,9 +1,8 @@
 from enum import Enum
-from typing import Any, Dict, FrozenSet, List, Literal, Optional, Set, Tuple, get_args
+from typing import Annotated, Any, Literal, Optional, get_args
 
 import pytest
 from annotated_types import Len
-from typing_extensions import Annotated
 
 from pydantic import BaseModel
 from pydantic.dataclasses import dataclass
@@ -14,7 +13,7 @@ from polyfactory.factories.pydantic_factory import ModelFactory
 MIN_MAX_PARAMETERS = ((10, 15), (20, 25), (30, 40), (40, 50))
 
 
-@pytest.mark.parametrize("type_", (List[int], Dict[int, int]))
+@pytest.mark.parametrize("type_", (list[int], dict[int, int]))
 @pytest.mark.parametrize("length", range(1, 10))
 def test_annotated_type_collection_length(type_: type, length: int) -> None:
     class Foo(BaseModel):
@@ -28,7 +27,7 @@ def test_annotated_type_collection_length(type_: type, length: int) -> None:
         assert len(foo.foo) == length, len(foo.foo)
 
 
-@pytest.mark.parametrize("type_", (List, Set))
+@pytest.mark.parametrize("type_", (list, set))
 @pytest.mark.parametrize(("min_val", "max_val"), MIN_MAX_PARAMETERS)
 def test_collection_length_with_list(min_val: int, max_val: int, type_: type) -> None:
     @dataclass
@@ -50,7 +49,7 @@ def test_collection_length_with_list(min_val: int, max_val: int, type_: type) ->
 def test_collection_length_with_set_collision() -> None:
     @dataclass
     class Foo:
-        foo: Set[int]
+        foo: set[int]
 
     provider_int_values_reversed = (list(range(9)) + list(range(7, 15)))[::-1]
 
@@ -61,7 +60,7 @@ def test_collection_length_with_set_collision() -> None:
         __max_collection_length__ = 10
 
         @classmethod
-        def get_provider_map(cls) -> Dict[Any, Any]:
+        def get_provider_map(cls) -> dict[Any, Any]:
             providers_map = super().get_provider_map()
             providers_map[int] = lambda: provider_int_values_reversed.pop()
             return providers_map
@@ -76,7 +75,7 @@ def test_collection_length_with_set_collision() -> None:
 def test_collection_length_with_tuple(min_val: int, max_val: int) -> None:
     @dataclass
     class Foo:
-        foo: Tuple[int, ...]
+        foo: tuple[int, ...]
 
     class FooFactory(DataclassFactory[Foo]):
         __model__ = Foo
@@ -94,7 +93,7 @@ def test_collection_length_with_tuple(min_val: int, max_val: int) -> None:
 def test_collection_length_with_dict(min_val: int, max_val: int) -> None:
     @dataclass
     class Foo:
-        foo: Dict[int, int]
+        foo: dict[int, int]
 
     class FooFactory(DataclassFactory[Foo]):
         __model__ = Foo
@@ -113,7 +112,7 @@ def test_collection_length_with_dict(min_val: int, max_val: int) -> None:
 def test_collection_length_with_optional_not_allowed(min_val: int, max_val: int) -> None:
     @dataclass
     class Foo:
-        foo: Optional[List[int]]
+        foo: Optional[list[int]]
 
     class FooFactory(DataclassFactory[Foo]):
         __model__ = Foo
@@ -134,7 +133,7 @@ def test_collection_length_with_optional_not_allowed(min_val: int, max_val: int)
 def test_collection_length_with_optional_allowed(min_val: int, max_val: int) -> None:
     @dataclass
     class Foo:
-        foo: Optional[List[int]]
+        foo: Optional[list[int]]
 
     class FooFactory(DataclassFactory[Foo]):
         __model__ = Foo
@@ -153,7 +152,7 @@ def test_collection_length_with_optional_allowed(min_val: int, max_val: int) ->
         assert len(foo.foo) <= max_val, len(foo.foo)
 
 
-@pytest.mark.parametrize("type_", (List, FrozenSet, Set))
+@pytest.mark.parametrize("type_", (list, frozenset, set))
 @pytest.mark.parametrize("min_items", (0, 2, 4))
 @pytest.mark.parametrize("max_inc", (0, 1, 4))
 def test_collection_length_with_literal(type_: type, min_items: int, max_inc: int) -> None:
@@ -175,7 +174,7 @@ def test_collection_length_with_literal(type_: type, min_items: int, max_inc: in
     assert len(result.animal_collection) <= max_items
 
 
-@pytest.mark.parametrize("type_", (List, FrozenSet, Set))
+@pytest.mark.parametrize("type_", (list, frozenset, set))
 @pytest.mark.parametrize("min_items", (0, 2, 4))
 @pytest.mark.parametrize("max_inc", (0, 1, 4))
 def test_collection_length_with_enum(type_: type, min_items: int, max_inc: int) -> None:
